<!--
https://pypi.org/project/readme-generator/
-->

[![](https://img.shields.io/pypi/pyversions/jsfiddle-generator.svg?longCache=True)](https://pypi.org/project/jsfiddle-generator/)

#### Installation
```bash
$ [sudo] pip install jsfiddle-generator
```

#### CLI
usage|`__doc__`
-|-
`python -m jsfiddle_generator path ...` |generate jsfiddle files: `demo.css`, `demo.js`, `demo.html`, `demo.details`

#### Examples
```bash
$ find . -name "demo.html" | sed 's#/[^/]*$$##' | xargs python -m jsfiddle_generator
```

#### Related projects
+   [`jsfiddle.py` - jsfiddle helper](https://pypi.org/project/jsfiddle/)
+   [`jsfiddle-build.py` - build html file from jsfiddle files](https://pypi.org/project/jsfiddle-build/)
+   [`jsfiddle-generator.py` - jsfiddle files generator](https://pypi.org/project/jsfiddle-generator/)
+   [`jsfiddle-readme.py` - generate jsfiddle `README.md`](https://pypi.org/project/jsfiddle-readme/)

#### Links
+   [Display fiddle from a Github repository](https://docs.jsfiddle.net/github-integration/untitled-1)

<p align="center">
    <a href="https://pypi.org/project/readme-generator/">readme-generator</a>
</p>